var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Author =
[
    [ "com::sun::star::text::TextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Author.html#ac5c12dd117b70431d72eeb6ab9507fd2", null ],
    [ "AuthorFormat", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Author.html#aae34b6192dd6d5a93321b82a9315fdd7", null ],
    [ "Content", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Author.html#a6d1fb265b40351e94f79e0f749e5daf9", null ],
    [ "CurrentPresentation", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Author.html#a632a1788f5e2e009b3809bbb266e39a0", null ],
    [ "FullName", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Author.html#ace688093658182cf396af7df0c9bc601", null ],
    [ "IsFixed", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Author.html#a57c3add6784f715a9bed21c3318f41ba", null ]
];